Learn R Programming

cumstats (version 1.0)

cumgmean: Cumulative Geometric Mean

Description

Returns a vector whose elements are the cumulative geometric mean of the elements of the argument.

Usage

cumgmean(x)

Arguments

x
a numeric vector.

Value

A numeric vector of the same length as x. An NA value in x causes the corresponding and following elements of the return value to be NA.

References

Kotz, S., Balakrishnan, N., Read, C.B, Vidakovic, B., Johnson, N.L. (2006) Encyclopedia of Statistical Sciences. Wiley, New Jersey.

See Also

cumhmean, cummean

Examples

Run this code
cumgmean(c(9, 1, 4, 0, 3, NA, 8, 5))

z <- cumgmean(rlnorm(10000, 0, 1))
head(z); tail(z)

Run the code above in your browser using DataLab