Learn R Programming

cumstats (version 1.0)

cummedian: Cumulative Median

Description

Returns a vector whose elements are the cumulative median of the elements of the argument.

Usage

cummedian(x)

Arguments

x
a numeric vector.

Value

A numeric vector of the same length as x. An NA value in x causes the corresponding and following elements of the return value to be NA.

References

Kotz, S., Balakrishnan, N., Read, C.B, Vidakovic, B., Johnson, N.L. (2006) Encyclopedia of Statistical Sciences. Wiley, New Jersey.

See Also

cummean, cumquant

Examples

Run this code
cummedian(c(9, 1, 4, 0, 3, NA, 8, 5))

Run the code above in your browser using DataLab