Learn R Programming

cumstats (version 1.0)

cumvar: Cumulative Variance

Description

Returns a vector whose elements are the cumulative sample variance of the elements of the argument.

Usage

cumvar(x)

Arguments

x
a numeric vector.

Value

A numeric vector of the same length as x. An NA value in x causes the corresponding and following elements of the return value to be NA. The first entry is always NA since sample variance requires at least two values.

References

Kotz, S., Balakrishnan, N., Read, C.B, Vidakovic, B., Johnson, N.L. (2006) Encyclopedia of Statistical Sciences. Wiley, New Jersey.

Examples

Run this code
cumvar(c(9, 1, 4, 0, 3, NA, 8, 5))

Run the code above in your browser using DataLab