Returns a vector whose elements are the cumulative skewness of the elements of the argument.
Usage
cumskew(x)
Arguments
x
a numeric vector.
Value
A numeric vector of the same length as x. An NA value in x causes the corresponding and following elements of the return value to be NA. The first entry is always NaN since skewness requires at least two different values.
References
Kotz, S., Balakrishnan, N., Read, C.B, Vidakovic, B., Johnson, N.L. (2006) Encyclopedia of Statistical Sciences. Wiley, New Jersey.